Cheshire3 Tutorials
===================

This section contains tutorials on configuring objects within the
:doc:`Cheshire3 Object Model </objects/index>` and then using them within a
Python_ scripting environment.


Tutorials:

.. toctree::
   :maxdepth: 1

   Command-line UI <commands>
   Python API <python>
   Configuring Databases <databases>
   Configuring Indexes <indexes>
   Configuring Stores <stores>
   Configuring Workflows <workflows>

.. Links
.. _Python: http://www.python.org/
